﻿<?xml version="1.0" encoding="utf-8"?>
<pattern id="Context" xmlns="http://purl.oclc.org/dsdl/schematron">
  <title>Context Validations</title>

  <rule context="xbrli:xbrl/xbrli:context[not(@i:nil='true' or @i:nil='1')]">

    <!-- Rule ID: VR.ATO.GEN.428253
         ELS Ref: V1200
      
        IF (INT:entity.identifier.ABN <> NULLORBLANK) AND (ABNALGORITHM (INT:entity.identifier.ABN) = FALSE)
          RETURN VALIDATION MESSAGE
        ENDIF
    -->
    <assert id="VR.ATO.GEN.428253" diagnostics="DVR.ATO.GEN.428253"
            test="not(                       
                        xbrli:entity/xbrli:identifier[upper-case(@scheme) = 'HTTP://WWW.ABR.GOV.AU/ABN'
                        and 
                        string-length(.) != 0
                        and 
                        not(function:ValidateABN(.))]
                     )"/>

    <!-- Rule ID: VR.ATO.GEN.500012
           ELS Ref: V2421

        IF (pyde.xx.xx:PersonDemographicDetails.Birth.Date <> NULL) AND (pyde.xx.xx:PersonDemographicDetails.Birth.Date > RP:period.startDate)
          RETURN VALIDATION MESSAGE
        ENDIF
    -->
    <assert id="VR.ATO.GEN.500012" diagnostics="DVR.ATO.GEN.500012"
            test="not(
                        . = $RP.Context
                        and 
                        $dd9[not(@i:nil='true' or @i:nil='1') and string-length(.) > 0]
                        and
                        function:IsDate1GreaterThanDate2($dd9[1], xbrli:period/xbrli:startDate)
                      )" />

    


    <!-- Rule ID: VR.ATO.GEN.500030
         ELS Ref: N/A
         
         IF period.startDate WHERE CONTEXT(ALL) <> RP:period.startDate
            RETURN VALIDATION MESSAGE
         ENDIF
    -->
    <let name="startDate" value="xbrli:period/xbrli:startDate"/>

    <assert id="VR.ATO.GEN.500030" diagnostics="DVR.ATO.GEN.500030"
            test="not(
                        preceding-sibling::xbrli:context/xbrli:period/xbrli:startDate[. != $startDate]
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.GEN.500034
         ELS Ref: N/A
         
         IF period.startDate <> period.endDate
             RETURN VALIDATION MESSAGE
         ENDIF
    -->
    <assert id="VR.ATO.GEN.500034" diagnostics="DVR.ATO.GEN.500034"
            test="not(
                        xbrli:period/xbrli:endDate[. != $startDate]
                     )"/>

    
    <!-- Rule ID: VR.ATO.GEN.500035
         ELS Ref: N/A
         
         IF period.startDate > DATE(TODAY)
             RETURN VALIDATION MESSAGE
         ENDIF
    -->
    <assert id="VR.ATO.GEN.500035" diagnostics="DVR.ATO.GEN.500035"
            test="not(
                        $startDate[function:IsDate1GreaterThanDate2(., current-date())]
                     )"/>
    
    
  </rule>

  <rule context="xbrli:xbrl[not(@i:nil='true')]">

    <!-- Rule ID: VR.ATO.GEN.000209
         ELS Ref: N/A

        IF COUNT(RP) <> 1
          RETURN VALIDATION MESSAGE
        ENDIF        
        
        THIS TEST IS UNDER THE TOP LEVEL AS IF IT WAS UNDER THE xbrli:context LEVEL THERE WOULD BE DUPLICATE ERROR MESSAGES PER CONTEXT
      -->
    <assert id="VR.ATO.GEN.000209" diagnostics="DVR.ATO.GEN.000209"
            test="not(
                        count($RP.Context) != 1
                      )" />


    <!-- Rule ID: VR.ATO.GEN.000227
         ELS Ref: N/A

        IF COUNT(INT) > 1
          RETURN VALIDATION MESSAGE
        ENDIF
        
        THIS TEST IS UNDER THE TOP LEVEL AS IF IT WAS UNDER THE xbrli:context LEVEL THERE WOULD BE DUPLICATE ERROR MESSAGES PER CONTEXT
    -->
    <assert id="VR.ATO.GEN.000227" diagnostics="DVR.ATO.GEN.000227"
            test="not(
                        count($INT.Context) > 1
                      )" />


    <!-- Rule ID: VR.ATO.GEN.438039
         ELS Ref: N/A
      
        IF (RprtPyType.xx.xx:ReportPartyTypeDimension = "RprtPyType.xx.xx:Intermediary") AND (entity.identifier.scheme <> "http://www.abr.gov.au/abn")
          RETURN VALIDATION MESSAGE
        ENDIF
    -->
    <assert id="VR.ATO.GEN.438039" diagnostics="DVR.ATO.GEN.438039"
                test="not(
                            $INT.Context
                            and
                            xbrli:context[@id = $INT.ContextId]/xbrli:entity/xbrli:identifier
                            [                            
                                not(matches(@scheme,'^http://www.abr.gov.au/abn$'))
                            ]                
                     )" />
    
    
    <!-- Rule ID: VR.ATO.DD.200011
         ELS Ref: N/A
      
        IF (RP:entity.identifier.scheme <> “http://www.abr.gov.au/abn”) AND (RP:entity.identifier.scheme <> “http://www.ato.gov.au/tfn”)
          RETURN VALIDATION MESSAGE
        ENDIF
    -->
    <assert id="VR.ATO.DD.200011" diagnostics="DVR.ATO.DD.200011"
            test="not(
                        $RP.Context/xbrli:entity/xbrli:identifier
                        [                            
                            not(matches(@scheme,'^http://www.abr.gov.au/abn$'))
                        ]
                        and
                        $RP.Context/xbrli:entity/xbrli:identifier
                        [                            
                            not(matches(@scheme,'^http://www.ato.gov.au/tfn$'))
                        ]
                     )" />


    <!-- Rule ID: VR.ATO.DD.200031
         ELS Ref: V1925D
      
         IF (RP:entity.identifier.scheme = “http://www.abr.gov.au/abn”) AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text = NULLORBLANK)
           RETURN VALIDATION MESSAGE
         ENDIF
    -->
    <assert id="VR.ATO.DD.200031" diagnostics="DVR.ATO.DD.200031"
            test="not(
                        $RP.Context/xbrli:entity/xbrli:identifier
                        [
                            upper-case(@scheme) = 'HTTP://WWW.ABR.GOV.AU/ABN'
                        ]
                        and
                        not($dd15[not(@i:nil='true') and string-length(.) != 0])
                     )" />
    

    <!-- Rule ID: VR.ATO.DD.200042
         ELS Ref: N/A
      
        IF RP:entity.identifier.scheme = “http://www.abr.gov.au/abn” AND INT:entity.identifier.ABN = RP:entity.identifier.ABN
            RETURN VALIDATION MESSAGE
        ENDIF
    -->
    <assert id="VR.ATO.DD.200042" diagnostics="DVR.ATO.DD.200042"
            test="not(                       
                        $INT.Context/xbrli:entity/xbrli:identifier
                        [
                          matches(@scheme,'^http://www.abr.gov.au/abn$')
                        ]
                        and
                        $RP.Context/xbrli:entity/xbrli:identifier
                        [
                          matches(@scheme,'^http://www.abr.gov.au/abn$')
                        ]
                        and
                        $INT.Context/xbrli:entity/xbrli:identifier = $RP.Context/xbrli:entity/xbrli:identifier
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.DD.200046
         ELS Ref: V1200
      
        IF (RP:entity.identifier.scheme = “http://www.abr.gov.au/abn”) AND (ABNALGORITHM(RP:entity.identier.ABN) = FALSE)
          RETURN VALIDATION MESSAGE
        ENDIF
    -->
    <assert id="VR.ATO.DD.200046" diagnostics="DVR.ATO.DD.200046"
			  test="not(                       
                        $RP.Context/xbrli:entity/xbrli:identifier
                        [
                            upper-case(@scheme) = 'HTTP://WWW.ABR.GOV.AU/ABN'
                            and 
                            string-length(.) != 0
                            and 
                            not(function:ValidateABN(.))
                        ]
                     )"/>
    
  


    <!-- Rule ID: VR.ATO.DD.200058
         ELS Ref: V20
      
        IF (RP:entity.identifier.scheme = “http://www.ato.gov.au/tfn”) AND (TFNALGORITHM (RP:entity.identifier.TFN) = FALSE)
          RETURN VALIDATION MESSAGE
        ENDIF
    -->
    <assert id="VR.ATO.DD.200058" diagnostics="DVR.ATO.DD.200058"
			  test="not(
                        $RP.Context/xbrli:entity/xbrli:identifier
                        [
                            upper-case(@scheme) = 'HTTP://WWW.ATO.GOV.AU/TFN'
                            and 
                            string-length(.) != 0
                            and 
                            not(function:ValidateTFN(.))
                        ]
                     )" />
    
  </rule>

  
  
</pattern>